@@ -39,12 +39,14 @@ Command::Command(const gchar* icon, const gchar* fallback_icon, const gchar* tex
 	m_status(CommandStatus::Unchecked),
 	m_timeout_details({nullptr, g_strdup(confirm_question), g_strdup(confirm_status), 0})
 {
-	const gchar* icons[] = {
-		icon,
-		fallback_icon,
-		nullptr
-	};
-	m_icon = g_themed_icon_new_from_names(const_cast<gchar**>(icons), -1);
+	if (gtk_icon_theme_has_icon(gtk_icon_theme_get_default(), icon))
+	{
+		m_icon = g_strdup(icon);
+	}
+	else
+	{
+		m_icon = g_strdup(fallback_icon);
+	}
 
 	std::string tooltip(text ? text : "");
 	for (auto i = tooltip.begin(); i != tooltip.end(); ++i)
@@ -74,7 +76,7 @@ Command::~Command()
 		g_object_unref(m_menuitem);
 	}
 
-	g_object_unref(m_icon);
+	g_free(m_icon);
 	g_free(m_mnemonic);
 	g_free(m_text);
 	g_free(m_command);
@@ -97,8 +99,7 @@ GtkWidget* Command::get_button()
 	gtk_widget_set_tooltip_text(m_button, m_text);
 	g_signal_connect_slot<GtkButton*>(m_button, "clicked", &Command::activate, this, Connect::After);
 
-	GtkWidget* image = gtk_image_new_from_gicon(m_icon, GTK_ICON_SIZE_LARGE_TOOLBAR);
-
+	GtkWidget* image = gtk_image_new_from_icon_name(m_icon, GTK_ICON_SIZE_LARGE_TOOLBAR);
 	gtk_container_add(GTK_CONTAINER(m_button), GTK_WIDGET(image));
 
 	gtk_widget_set_visible(m_button, m_shown);
@@ -242,7 +243,7 @@ bool Command::confirm()
 	gtk_window_set_titlebar(window, header);
 
 	// Add icon
-	GtkWidget* image = gtk_image_new_from_gicon(m_icon, GTK_ICON_SIZE_DIALOG);
+	GtkWidget* image = gtk_image_new_from_icon_name(m_icon, GTK_ICON_SIZE_DIALOG);
 	gtk_widget_show(image);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	gtk_message_dialog_set_image(GTK_MESSAGE_DIALOG(dialog), image);
@@ -250,7 +251,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
 	// Create accept button
 	GtkWidget* button = gtk_dialog_add_button(dialog, m_mnemonic, GTK_RESPONSE_ACCEPT);
-	image = gtk_image_new_from_gicon(m_icon, GTK_ICON_SIZE_BUTTON);
+	image = gtk_image_new_from_icon_name(m_icon, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image(GTK_BUTTON(button), image);
 	gtk_dialog_set_default_response(dialog, GTK_RESPONSE_ACCEPT);
 
