@@ -17,6 +17,7 @@
 
 #include "page.h"
 
+#include "category-button.h"
 #include "favorites-page.h"
 #include "image-menu-item.h"
 #include "launcher.h"
@@ -35,13 +36,22 @@ using namespace WhiskerMenu;
 
 //-----------------------------------------------------------------------------
 
-Page::Page(Window* window) :
+Page::Page(Window* window, const gchar* icon, const gchar* text) :
 	m_window(window),
+	m_button(nullptr),
 	m_selected_launcher(nullptr),
 	m_drag_enabled(true),
 	m_launcher_dragged(false),
 	m_reorderable(false)
 {
+	// Create button
+	if (icon && text)
+	{
+		GIcon* gicon = g_themed_icon_new(icon);
+		m_button = new CategoryButton(gicon, text);
+		g_object_unref(gicon);
+	}
+
 	// Create view
 	create_view();
 
@@ -57,6 +67,7 @@ Page::Page(Window* window) :
 
 Page::~Page()
 {
+	delete m_button;
 	delete m_view;
 	gtk_widget_destroy(m_widget);
 	g_object_unref(m_widget);
@@ -68,22 +79,31 @@ void Page::reset_selection()
 {
 	m_view->collapse_all();
 
-	// Set keyboard focus on first item
+	// Set keyboard focus on first item and scroll to top
+	select_first();
+
+	// Clear selection
+	m_view->clear_selection();
+}
+
+//-----------------------------------------------------------------------------
+
+void Page::select_first()
+{
+	// Select and set keyboard focus on first item
 	GtkTreeModel* model = m_view->get_model();
 	GtkTreeIter iter;
 	if (model && gtk_tree_model_get_iter_first(model, &iter))
 	{
 		GtkTreePath* path = gtk_tree_model_get_path(model, &iter);
 		m_view->set_cursor(path);
+		m_view->select_path(path);
 		gtk_tree_path_free(path);
 	}
 
 	// Scroll to top
 	GtkAdjustment* adjustment = gtk_scrollable_get_vadjustment(GTK_SCROLLABLE(m_view->get_widget()));
 	gtk_adjustment_set_value(adjustment, gtk_adjustment_get_lower(adjustment));
-
-	// Clear selection
-	m_view->clear_selection();
 }
 
 //-----------------------------------------------------------------------------
@@ -236,18 +256,18 @@ gboolean Page::view_button_press_event(GtkWidget*, GdkEvent* event)
 	GtkTreePath* path = m_view->get_path_at_pos(button_event->x, button_event->y);
 	if (!path)
 	{
-		return false;
+		return GDK_EVENT_PROPAGATE;
 	}
 
-	if (button_event->button == 3)
+	if (gdk_event_triggers_context_menu(event))
 	{
 		create_context_menu(path, event);
-		return true;
+		return GDK_EVENT_STOP;
 	}
-	else if (button_event->button != 1)
+	else if (button_event->button != GDK_BUTTON_PRIMARY)
 	{
 		gtk_tree_path_free(path);
-		return false;
+		return GDK_EVENT_PROPAGATE;
 	}
 
 	Element* element = nullptr;
@@ -268,7 +288,9 @@ gboolean Page::view_button_press_event(GtkWidget*, GdkEvent* event)
 		set_reorderable(m_reorderable);
 	}
 
-	return false;
+	m_window->set_child_has_focus();
+
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -278,7 +300,7 @@ gboolean Page::view_button_release_event(GtkWidget*, GdkEvent* event)
 	GdkEventButton* button_event = reinterpret_cast<GdkEventButton*>(event);
 	if (button_event->button != 1)
 	{
-		return false;
+		return GDK_EVENT_PROPAGATE;
 	}
 
 	if (m_launcher_dragged)
@@ -287,7 +309,7 @@ gboolean Page::view_button_release_event(GtkWidget*, GdkEvent* event)
 		m_launcher_dragged = false;
 	}
 
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -327,12 +349,12 @@ gboolean Page::view_popup_menu_event(GtkWidget*)
 	GtkTreePath* path = m_view->get_cursor();
 	if (!path)
 	{
-		return false;
+		return GDK_EVENT_PROPAGATE;
 	}
 
 	create_context_menu(path, nullptr);
 
-	return true;
+	return GDK_EVENT_STOP;
 }
 
 //-----------------------------------------------------------------------------
@@ -385,7 +407,7 @@ void Page::create_context_menu(GtkTreePath* path, GdkEvent* event)
 	}
 	else
 	{
-		menuitem = whiskermenu_image_menu_item_new("list-remove", _("Remove From Favorites"));
+		menuitem = whiskermenu_image_menu_item_new("list-remove", _("Remove from Favorites"));
 		g_signal_connect_slot<GtkMenuItem*>(menuitem, "activate", &Page::remove_selected_from_favorites, this);
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 	}
@@ -414,6 +436,7 @@ void Page::create_context_menu(GtkTreePath* path, GdkEvent* event)
 	gtk_widget_show_all(menu);
 
 	// Show context menu
+	m_window->set_child_has_focus();
 	gtk_menu_attach_to_widget(GTK_MENU(menu), m_view->get_widget(), nullptr);
 	gtk_menu_popup_at_pointer(GTK_MENU(menu), event);
 
@@ -429,8 +452,6 @@ void Page::destroy_context_menu(GtkMenuShell* menu)
 	m_selected_launcher = nullptr;
 
 	gtk_widget_destroy(GTK_WIDGET(menu));
-
-	m_window->on_context_menu_destroyed();
 }
 
 //-----------------------------------------------------------------------------
@@ -535,12 +556,11 @@ void Page::edit_selected()
 
 	m_window->hide();
 
-	GError* error = nullptr;
 	gchar* uri = m_selected_launcher->get_uri();
-	gchar* quoted_uri = g_shell_quote(uri);
-	gchar* command = g_strconcat("exo-desktop-item-edit ", quoted_uri, nullptr);
+	gchar* command = g_strdup_printf("exo-desktop-item-edit '%s'", uri);
 	g_free(uri);
-	g_free(quoted_uri);
+
+	GError* error = nullptr;
 	if (!g_spawn_command_line_async(command, &error))
 	{
 		xfce_dialog_show_error(nullptr, error, _("Unable to edit launcher."));
