@@ -95,7 +95,8 @@ Plugin::Plugin(XfcePanelPlugin* plugin) :
 	m_plugin(plugin),
 	m_window(nullptr),
 	m_opacity(100),
-	m_file_icon(false)
+	m_file_icon(false),
+	m_focus_out_time(0)
 {
 	// Load settings
 	wm_settings = new Settings;
@@ -137,11 +138,16 @@ Plugin::Plugin(XfcePanelPlugin* plugin) :
 
 	m_button_icon = GTK_IMAGE(gtk_image_new());
 	icon_changed(wm_settings->button_icon_name.c_str());
+	gtk_widget_set_tooltip_markup(m_button, wm_settings->button_title.c_str());
 	gtk_box_pack_start(m_button_box, GTK_WIDGET(m_button_icon), true, false, 0);
 	if (wm_settings->button_icon_visible)
 	{
 		gtk_widget_show(GTK_WIDGET(m_button_icon));
 	}
+	if (wm_settings->button_title_visible)
+	{
+		gtk_widget_set_has_tooltip(m_button, false);
+	}
 	gtk_widget_set_sensitive(GTK_WIDGET(m_button_icon), false);
 
 	m_button_label = GTK_LABEL(gtk_label_new(nullptr));
@@ -249,10 +255,12 @@ void Plugin::set_button_style(ButtonStyle style)
 	if (wm_settings->button_title_visible)
 	{
 		gtk_widget_show(GTK_WIDGET(m_button_label));
+		gtk_widget_set_has_tooltip(m_button, false);
 	}
 	else
 	{
 		gtk_widget_hide(GTK_WIDGET(m_button_label));
+		gtk_widget_set_has_tooltip(m_button, true);
 	}
 
 	wm_settings->set_modified();
@@ -267,6 +275,8 @@ void Plugin::set_button_title(const std::string& title)
 	wm_settings->button_title = title;
 	wm_settings->set_modified();
 	gtk_label_set_markup(m_button_label, wm_settings->button_title.c_str());
+	gtk_widget_set_tooltip_markup(m_button, wm_settings->button_title.c_str());
+	gtk_widget_set_has_tooltip(m_button, !wm_settings->button_title_visible);
 	size_changed(m_plugin, xfce_panel_plugin_get_size(m_plugin));
 }
 
@@ -370,6 +380,18 @@ gboolean Plugin::remote_event(XfcePanelPlugin*, gchar* name, GValue* value)
 		return false;
 	}
 
+	// Ignore event if menu lost focus and hid within last 1/4 second;
+	// needed for toggling as remote event happens after focus is lost
+	if (m_focus_out_time)
+	{
+		if ((g_get_monotonic_time() - m_focus_out_time) < 250000)
+		{
+			m_focus_out_time = 0;
+			return true;
+		}
+		m_focus_out_time = 0;
+	}
+
 	if (gtk_widget_get_visible(m_window->get_widget()))
 	{
 		m_window->hide();
@@ -551,6 +573,7 @@ void Plugin::show_menu(bool at_cursor)
 		m_opacity = wm_settings->menu_opacity;
 	}
 	m_window->show(at_cursor ? Window::PositionAtCursor : Window::Position(xfce_panel_plugin_get_orientation(m_plugin)));
+	m_focus_out_time = 0;
 }
 
 //-----------------------------------------------------------------------------
