@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2015 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013-2020 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,9 +27,8 @@ namespace WhiskerMenu
 class Query
 {
 public:
-	Query();
+	Query() = default;
 	explicit Query(const std::string& query);
-	~Query();
 
 	bool empty() const
 	{
