@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2015 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013-2020 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ namespace WhiskerMenu
 class RecentPage : public Page
 {
 public:
-	RecentPage(Window* window);
+	explicit RecentPage(Window* window);
 	~RecentPage();
 
 	void add(Launcher* launcher);
