@@ -20,8 +20,6 @@
 #include "query.h"
 #include "settings.h"
 
-#include <libxfce4ui/libxfce4ui.h>
-
 using namespace WhiskerMenu;
 
 //-----------------------------------------------------------------------------
@@ -35,12 +33,7 @@ RunAction::RunAction()
 
 void RunAction::run(GdkScreen* screen) const
 {
-	GError* error = nullptr;
-	if (!xfce_spawn_command_line_on_screen(screen, m_command_line.c_str(), false, false, &error))
-	{
-		xfce_dialog_show_error(nullptr, error, _("Failed to execute command \"%s\"."), m_command_line.c_str());
-		g_error_free(error);
-	}
+	spawn(screen, m_command_line.c_str(), nullptr, false, nullptr);
 }
 
 //-----------------------------------------------------------------------------
