@@ -23,6 +23,7 @@
 #include "search-action.h"
 #include "settings.h"
 #include "slot.h"
+#include "util.h"
 #include "window.h"
 
 #include <algorithm>
@@ -140,17 +141,7 @@ void SearchPage::set_filter(const gchar* filter)
 	g_object_unref(store);
 
 	// Find first result
-	GtkTreeIter iter;
-	GtkTreePath* path = gtk_tree_path_new_first();
-	bool found = gtk_tree_model_get_iter(get_view()->get_model(), &iter, path);
-
-	// Scroll to and select first result
-	if (found)
-	{
-		get_view()->select_path(path);
-		get_view()->scroll_to_path(path);
-	}
-	gtk_tree_path_free(path);
+	select_first();
 }
 
 //-----------------------------------------------------------------------------
@@ -192,7 +183,7 @@ void SearchPage::activate_search(GtkEntry* entry)
 void SearchPage::cancel_search(GtkSearchEntry* entry)
 {
 	const gchar* text = gtk_entry_get_text(GTK_ENTRY(entry));
-	if (!exo_str_is_empty(text))
+	if (!xfce_str_is_empty(text))
 	{
 		gtk_entry_set_text(GTK_ENTRY(entry), "");
 	}
