@@ -299,7 +299,7 @@ void SettingsDialog::title_changed(GtkEditable* editable)
 
 void SettingsDialog::choose_icon()
 {
-	GtkWidget* chooser = exo_icon_chooser_dialog_new(_("Select An Icon"),
+	GtkWidget* chooser = exo_icon_chooser_dialog_new(_("Select an Icon"),
 			GTK_WINDOW(m_window),
 			_("_Cancel"), GTK_RESPONSE_CANCEL,
 			_("_OK"), GTK_RESPONSE_ACCEPT,
@@ -345,15 +345,48 @@ void SettingsDialog::toggle_stay_on_focus_out(GtkToggleButton* button)
 
 //-----------------------------------------------------------------------------
 
+void SettingsDialog::toggle_display_favorites(GtkToggleButton* button)
+{
+	if (gtk_toggle_button_get_active(button))
+	{
+		wm_settings->default_category = 0;
+		wm_settings->set_modified();
+	}
+}
+
+//-----------------------------------------------------------------------------
+
+void SettingsDialog::toggle_display_recent(GtkToggleButton* button)
+{
+	if (gtk_toggle_button_get_active(button))
+	{
+		wm_settings->default_category = 1;
+		wm_settings->set_modified();
+	}
+}
+
+//-----------------------------------------------------------------------------
+
+void SettingsDialog::toggle_display_applications(GtkToggleButton *button)
+{
+	if (gtk_toggle_button_get_active(button))
+	{
+		wm_settings->default_category = 2;
+		wm_settings->set_modified();
+	}
+}
+
+//-----------------------------------------------------------------------------
+
 void SettingsDialog::recent_items_max_changed(GtkSpinButton* button)
 {
 	wm_settings->recent_items_max = gtk_spin_button_get_value_as_int(button);
 	wm_settings->set_modified();
 	const bool active = wm_settings->recent_items_max;
 	gtk_widget_set_sensitive(GTK_WIDGET(m_display_recent), active);
-	if (!active)
+	if (!active && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_display_recent)))
 	{
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_recent), false);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_favorites), true);
 	}
 }
 
@@ -367,14 +400,6 @@ void SettingsDialog::toggle_remember_favorites(GtkToggleButton* button)
 
 //-----------------------------------------------------------------------------
 
-void SettingsDialog::toggle_display_recent(GtkToggleButton* button)
-{
-	wm_settings->display_recent = gtk_toggle_button_get_active(button);
-	wm_settings->set_modified();
-}
-
-//-----------------------------------------------------------------------------
-
 void SettingsDialog::toggle_confirm_session_command(GtkToggleButton* button)
 {
 	wm_settings->confirm_session_command = gtk_toggle_button_get_active(button);
@@ -612,12 +637,12 @@ GtkWidget* SettingsDialog::init_appearance_tab()
 	// Add option to show as icons
 	m_show_as_icons = gtk_radio_button_new_with_mnemonic(nullptr, _("Show as _icons"));
 	{
-		gchar* icons[] = {
-			g_strdup("view-list-icons"),
-			g_strdup("view-grid"),
+		const gchar* icons[] = {
+			"view-list-icons",
+			"view-grid",
 			nullptr
 		};
-		GIcon* gicon = g_themed_icon_new_from_names(icons, -1);
+		GIcon* gicon = g_themed_icon_new_from_names(const_cast<gchar**>(icons), -1);
 		gtk_button_set_image(GTK_BUTTON(m_show_as_icons), gtk_image_new_from_gicon(gicon, GTK_ICON_SIZE_DND));
 		g_object_unref(gicon);
 	}
@@ -629,13 +654,13 @@ GtkWidget* SettingsDialog::init_appearance_tab()
 	// Add option to show as list
 	m_show_as_list = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(m_show_as_icons), _("Show as lis_t"));
 	{
-		gchar* icons[] = {
-			g_strdup("view-list-compact"),
-			g_strdup("view-list-details"),
-			g_strdup("view-list"),
+		const gchar* icons[] = {
+			"view-list-compact",
+			"view-list-details",
+			"view-list",
 			nullptr
 		};
-		GIcon* gicon = g_themed_icon_new_from_names(icons, -1);
+		GIcon* gicon = g_themed_icon_new_from_names(const_cast<gchar**>(icons), -1);
 		gtk_button_set_image(GTK_BUTTON(m_show_as_list), gtk_image_new_from_gicon(gicon, GTK_ICON_SIZE_DND));
 		g_object_unref(gicon);
 	}
@@ -647,13 +672,13 @@ GtkWidget* SettingsDialog::init_appearance_tab()
 	// Add option to show as tree
 	m_show_as_tree = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(m_show_as_list), _("Show as t_ree"));
 	{
-		gchar* icons[] = {
-			g_strdup("view-list-tree"),
-			g_strdup("view-list-details"),
-			g_strdup("pan-end"),
+		const gchar* icons[] = {
+			"view-list-tree",
+			"view-list-details",
+			"pan-end",
 			nullptr
 		};
-		GIcon* gicon = g_themed_icon_new_from_names(icons, -1);
+		GIcon* gicon = g_themed_icon_new_from_names(const_cast<gchar**>(icons), -1);
 		gtk_button_set_image(GTK_BUTTON(m_show_as_tree), gtk_image_new_from_gicon(gicon, GTK_ICON_SIZE_DND));
 		g_object_unref(gicon);
 	}
@@ -865,6 +890,43 @@ GtkWidget* SettingsDialog::init_behavior_tab()
 	gtk_container_set_border_width(GTK_CONTAINER(page), 12);
 
 
+	// Create default display section
+	GtkBox* display_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
+	GtkWidget* display_frame = make_aligned_frame(_("Default Category"), GTK_WIDGET(display_vbox));
+	gtk_box_pack_start(page, display_frame, false, false, 0);
+
+	// Add option to display favorites
+	m_display_favorites = gtk_radio_button_new_with_mnemonic(nullptr, _("Favorites"));
+	gtk_box_pack_start(display_vbox, m_display_favorites, true, true, 0);
+
+	// Add option to display recently used
+	m_display_recent = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(m_display_favorites), _("Recently Used"));
+	gtk_box_pack_start(display_vbox, m_display_recent, true, true, 0);
+	gtk_widget_set_sensitive(GTK_WIDGET(m_display_recent), wm_settings->recent_items_max);
+
+	// Add option to display all applications
+	m_display_applications = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(m_display_recent), _("All Applications"));
+	gtk_box_pack_start(display_vbox, m_display_applications, true, true, 0);
+
+	switch (wm_settings->default_category)
+	{
+	case 1:
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_recent), true);
+		break;
+
+	case 2:
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_applications), true);
+		break;
+
+	default:
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_favorites), true);
+		break;
+	}
+	g_signal_connect_slot(m_display_favorites, "toggled", &SettingsDialog::toggle_display_favorites, this);
+	g_signal_connect_slot(m_display_recent, "toggled", &SettingsDialog::toggle_display_recent, this);
+	g_signal_connect_slot(m_display_applications, "toggled", &SettingsDialog::toggle_display_applications, this);
+
+
 	// Create menu section
 	GtkBox* behavior_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
 	GtkWidget* behavior_frame = make_aligned_frame(_("Menu"), GTK_WIDGET(behavior_vbox));
@@ -908,13 +970,6 @@ GtkWidget* SettingsDialog::init_behavior_tab()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_remember_favorites), wm_settings->favorites_in_recent);
 	g_signal_connect_slot(m_remember_favorites, "toggled", &SettingsDialog::toggle_remember_favorites, this);
 
-	// Add option to display recently used
-	m_display_recent = gtk_check_button_new_with_mnemonic(_("Display by _default"));
-	gtk_grid_attach(recent_table, m_display_recent, 0, 2, 2, 1);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_display_recent), wm_settings->display_recent);
-	gtk_widget_set_sensitive(GTK_WIDGET(m_display_recent), wm_settings->recent_items_max);
-	g_signal_connect_slot(m_display_recent, "toggled", &SettingsDialog::toggle_display_recent, this);
-
 
 	// Create command buttons section
 	GtkBox* command_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
