@@ -45,6 +45,7 @@ class Settings
 	void load(gchar* file);
 	void save(gchar* file);
 
+	std::string m_button_title_default;
 	bool m_modified;
 
 public:
@@ -82,9 +83,10 @@ public:
 	bool load_hierarchy;
 	bool view_as_icons;
 
+	int default_category;
+
 	decltype(recent.size()) recent_items_max;
 	bool favorites_in_recent;
-	bool display_recent;
 
 	bool position_search_alternate;
 	bool position_commands_alternate;
