@@ -29,8 +29,8 @@
 #include "search-page.h"
 #include "settings.h"
 #include "slot.h"
+#include "util.h"
 
-#include <exo/exo.h>
 #include <gdk/gdkkeysyms.h>
 #include <libxfce4ui/libxfce4ui.h>
 
@@ -40,33 +40,6 @@ using namespace WhiskerMenu;
 
 //-----------------------------------------------------------------------------
 
-static void grab_pointer(GtkWidget* widget)
-{
-	if (wm_settings->stay_on_focus_out)
-	{
-		return;
-	}
-
-	GdkDisplay* display = gdk_display_get_default();
-	GdkSeat* seat = gdk_display_get_default_seat(display);
-	GdkWindow* window = gtk_widget_get_window(widget);
-	gdk_seat_grab(seat, window, GDK_SEAT_CAPABILITY_ALL_POINTING, true, nullptr, nullptr, nullptr, nullptr);
-}
-
-static void ungrab_pointer()
-{
-	if (wm_settings->stay_on_focus_out)
-	{
-		return;
-	}
-
-	GdkDisplay* display = gdk_display_get_default();
-	GdkSeat* seat = gdk_display_get_default_seat(display);
-	gdk_seat_ungrab(seat);
-}
-
-//-----------------------------------------------------------------------------
-
 WhiskerMenu::Window::Window(Plugin* plugin) :
 	m_plugin(plugin),
 	m_window(nullptr),
@@ -79,7 +52,8 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	m_layout_categories_alternate(false),
 	m_layout_search_alternate(false),
 	m_layout_commands_alternate(false),
-	m_supports_alpha(false)
+	m_supports_alpha(false),
+	m_child_has_focus(false)
 {
 	// Create the window
 	m_window = GTK_WINDOW(gtk_window_new(GTK_WINDOW_TOPLEVEL));
@@ -92,13 +66,12 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	gtk_window_set_skip_pager_hint(m_window, true);
 	gtk_window_set_type_hint(m_window, GDK_WINDOW_TYPE_HINT_POPUP_MENU);
 	gtk_window_stick(m_window);
-	gtk_widget_add_events(GTK_WIDGET(m_window), GDK_BUTTON_PRESS_MASK | GDK_LEAVE_NOTIFY_MASK | GDK_STRUCTURE_MASK);
-	g_signal_connect_slot(m_window, "enter-notify-event", &Window::on_enter_notify_event, this);
-	g_signal_connect_slot(m_window, "leave-notify-event", &Window::on_leave_notify_event, this);
-	g_signal_connect_slot(m_window, "button-press-event", &Window::on_button_press_event, this);
-	g_signal_connect_slot(m_window, "button-release-event", &Window::on_button_release_event, this);
+	gtk_widget_add_events(GTK_WIDGET(m_window), GDK_FOCUS_CHANGE_MASK | GDK_STRUCTURE_MASK);
+	g_signal_connect_slot(m_window, "enter-notify-event", &Window::on_focus_in_event, this);
+	g_signal_connect_slot(m_window, "focus-in-event", &Window::on_focus_in_event, this);
+	g_signal_connect_slot(m_window, "focus-out-event", &Window::on_focus_out_event, this);
 	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event, this);
-	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event_after, this, true);
+	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event_after, this, Connect::After);
 	g_signal_connect_slot(m_window, "map-event", &Window::on_map_event, this);
 	g_signal_connect_slot(m_window, "state-flags-changed", &Window::on_state_flags_changed_event, this);
 	g_signal_connect_slot(m_window, "configure-event", &Window::on_configure_event, this);
@@ -121,6 +94,8 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 
 	// Create the profile picture
 	m_profilepic = new ProfilePicture(this);
+	gtk_widget_set_margin_top(m_profilepic->get_widget(), 2);
+	gtk_widget_set_margin_bottom(m_profilepic->get_widget(), 2);
 
 	// Create the username label
 	const gchar* name = g_get_real_name();
@@ -141,49 +116,38 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 		m_command_slots[i] = g_signal_connect_slot<GtkButton*>(m_commands_button[i], "clicked", &Window::hide, this);
 	}
 
-	m_resizer = new ResizeGrip(m_window);
+	m_resizer = new ResizeGrip(this);
 
 	// Create search entry
 	m_search_entry = GTK_ENTRY(gtk_search_entry_new());
 	g_signal_connect_slot<GtkSearchEntry*>(m_search_entry, "changed", &Window::search, this);
+	g_signal_connect_slot<GtkEntry*,GtkWidget*>(m_search_entry, "populate-popup", &Window::set_child_has_focus, this);
 
 	// Create favorites
 	m_favorites = new FavoritesPage(this);
 
-	GIcon* icon = g_themed_icon_new("user-bookmarks");
-	m_favorites_button = new CategoryButton(icon, _("Favorites"));
-	g_object_unref(icon);
-	g_signal_connect_slot<GtkToggleButton*>(m_favorites_button->get_widget(), "toggled", &Window::favorites_toggled, this);
+	CategoryButton* favorites_button = m_favorites->get_button();
+	g_signal_connect_slot<GtkToggleButton*>(favorites_button->get_widget(), "toggled", &Window::favorites_toggled, this);
 
 	// Create recent
 	m_recent = new RecentPage(this);
 
-	icon = g_themed_icon_new("document-open-recent");
-	m_recent_button = new CategoryButton(icon, _("Recently Used"));
-	g_object_unref(icon);
-	m_recent_button->join_group(m_favorites_button);
-	g_signal_connect_slot<GtkToggleButton*>(m_recent_button->get_widget(), "toggled", &Window::recent_toggled, this);
+	CategoryButton* recent_button = m_recent->get_button();
+	recent_button->join_group(favorites_button);
+	g_signal_connect_slot<GtkToggleButton*>(recent_button->get_widget(), "toggled", &Window::recent_toggled, this);
 
 	// Create applications
 	m_applications = new ApplicationsPage(this);
 
+	CategoryButton* applications_button = m_applications->get_button();
+	applications_button->join_group(recent_button);
+	g_signal_connect_slot<GtkToggleButton*>(applications_button->get_widget(), "toggled", &Window::category_toggled, this);
+
 	// Create search results
 	m_search_results = new SearchPage(this);
 
-	// Handle default page
-	if (!wm_settings->display_recent)
-	{
-		m_default_button = m_favorites_button;
-		m_default_page = m_favorites;
-	}
-	else
-	{
-		m_default_button = m_recent_button;
-		m_default_page = m_recent;
-	}
-
 	// Create box for packing children
-	m_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 6));
+	m_vbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 0));
 	gtk_container_set_border_width(GTK_CONTAINER(m_vbox), 2);
 	gtk_stack_add_named(m_window_stack, GTK_WIDGET(m_vbox), "contents");
 
@@ -203,11 +167,13 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	gtk_box_pack_start(m_title_box, GTK_WIDGET(m_username), true, true, 0);
 	gtk_box_pack_start(m_title_box, GTK_WIDGET(m_commands_box), false, false, 0);
 	gtk_box_pack_start(m_title_box, GTK_WIDGET(m_resizer->get_widget()), false, false, 0);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(m_title_box), gtk_container_get_border_width(GTK_CONTAINER(m_vbox)));
 
 	// Add search to layout
 	m_search_box = GTK_BOX(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 6));
 	gtk_box_pack_start(m_vbox, GTK_WIDGET(m_search_box), false, true, 0);
 	gtk_box_pack_start(m_search_box, GTK_WIDGET(m_search_entry), true, true, 0);
+	gtk_widget_set_margin_bottom(GTK_WIDGET(m_search_box), 6);
 
 	// Create box for packing launcher pages and sidebar
 	m_contents_stack = GTK_STACK(gtk_stack_new());
@@ -225,8 +191,9 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 
 	// Create box for packing sidebar
 	m_sidebar_buttons = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, 0));
-	gtk_box_pack_start(m_sidebar_buttons, m_favorites_button->get_widget(), false, false, 0);
-	gtk_box_pack_start(m_sidebar_buttons, m_recent_button->get_widget(), false, false, 0);
+	gtk_box_pack_start(m_sidebar_buttons, favorites_button->get_widget(), false, false, 0);
+	gtk_box_pack_start(m_sidebar_buttons, recent_button->get_widget(), false, false, 0);
+	gtk_box_pack_start(m_sidebar_buttons, applications_button->get_widget(), false, false, 0);
 	gtk_box_pack_start(m_sidebar_buttons, gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), false, false, 4);
 
 	m_sidebar = GTK_SCROLLED_WINDOW(gtk_scrolled_window_new(nullptr, nullptr));
@@ -235,6 +202,9 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	gtk_scrolled_window_set_policy(m_sidebar, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_container_add(GTK_CONTAINER(m_sidebar), GTK_WIDGET(m_sidebar_buttons));
 
+	// Handle default page
+	reset_default_button();
+
 	// Show widgets
 	gtk_widget_show_all(frame);
 	m_default_button->set_active(true);
@@ -272,9 +242,6 @@ WhiskerMenu::Window::~Window()
 	delete m_profilepic;
 	delete m_resizer;
 
-	delete m_favorites_button;
-	delete m_recent_button;
-
 	gtk_widget_destroy(GTK_WIDGET(m_window));
 	g_object_unref(m_window);
 }
@@ -283,15 +250,10 @@ WhiskerMenu::Window::~Window()
 
 void WhiskerMenu::Window::hide()
 {
-	ungrab_pointer();
-
 	// Scroll categories to top
 	GtkAdjustment* adjustment = gtk_scrolled_window_get_vadjustment(m_sidebar);
 	gtk_adjustment_set_value(adjustment, gtk_adjustment_get_lower(adjustment));
 
-	// Reset any pressed category buttons
-	unset_pressed_category();
-
 	// Hide command buttons to remove active border
 	for (auto command : m_commands_button)
 	{
@@ -342,7 +304,7 @@ void WhiskerMenu::Window::show(const Position position)
 	m_recent->enforce_item_count();
 
 	// Make sure recent button is only visible when tracked
-	gtk_widget_set_visible(m_recent_button->get_widget(), wm_settings->recent_items_max);
+	gtk_widget_set_visible(m_recent->get_button()->get_widget(), wm_settings->recent_items_max);
 
 	// Make sure applications list is current; does nothing unless list has changed
 	if (m_applications->load())
@@ -357,21 +319,14 @@ void WhiskerMenu::Window::show(const Position position)
 	}
 
 	// Update default page
-	if (wm_settings->display_recent)
-	{
-		m_default_button = m_recent_button;
-		m_default_page = m_recent;
-	}
-	else
-	{
-		m_default_button = m_favorites_button;
-		m_default_page = m_favorites;
-	}
+	reset_default_button();
 	show_default_page();
 
 	// Make sure icon sizes are correct
-	m_favorites_button->reload_icon_size();
-	m_recent_button->reload_icon_size();
+	m_favorites->get_button()->reload_icon_size();
+	m_recent->get_button()->reload_icon_size();
+	m_applications->get_button()->reload_icon_size();
+
 	m_applications->reload_category_icon_size();
 
 	m_search_results->get_view()->reload_icon_size();
@@ -513,7 +468,7 @@ void WhiskerMenu::Window::show(const Position position)
 	}
 
 	// Show window
-	gtk_widget_show(GTK_WIDGET(m_window));
+	gtk_window_present(m_window);
 	gtk_window_move(m_window, m_geometry.x, m_geometry.y);
 }
 
@@ -535,16 +490,16 @@ void WhiskerMenu::Window::save()
 
 //-----------------------------------------------------------------------------
 
-void WhiskerMenu::Window::on_context_menu_destroyed()
+void WhiskerMenu::Window::set_child_has_focus()
 {
-	grab_pointer(GTK_WIDGET(m_window));
+	m_child_has_focus = true;
 }
 
 //-----------------------------------------------------------------------------
 
 void WhiskerMenu::Window::set_categories(const std::vector<CategoryButton*>& categories)
 {
-	CategoryButton* last_button = m_recent_button;
+	CategoryButton* last_button = m_applications->get_button();
 	for (auto button : categories)
 	{
 		button->join_group(last_button);
@@ -553,12 +508,6 @@ void WhiskerMenu::Window::set_categories(const std::vector<CategoryButton*>& cat
 		g_signal_connect_slot<GtkToggleButton*>(button->get_widget(), "toggled", &Window::category_toggled, this);
 	}
 
-	// Position "All Applications" above divider
-	if (!categories.empty())
-	{
-		gtk_box_reorder_child(m_sidebar_buttons, categories.front()->get_widget(), 2);
-	}
-
 	show_default_page();
 }
 
@@ -604,64 +553,28 @@ void WhiskerMenu::Window::unset_items()
 
 //-----------------------------------------------------------------------------
 
-gboolean WhiskerMenu::Window::on_enter_notify_event(GtkWidget*, GdkEvent* event)
+gboolean WhiskerMenu::Window::on_focus_in_event(GtkWidget*, GdkEvent*)
 {
-	GdkEventCrossing* crossing_event = reinterpret_cast<GdkEventCrossing*>(event);
-	if ((crossing_event->detail == GDK_NOTIFY_INFERIOR)
-			|| (crossing_event->mode == GDK_CROSSING_GRAB)
-			|| (crossing_event->mode == GDK_CROSSING_GTK_GRAB))
-	{
-		return false;
-	}
-
-	grab_pointer(GTK_WIDGET(m_window));
-
-	return false;
+	m_child_has_focus = false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
 
-gboolean WhiskerMenu::Window::on_leave_notify_event(GtkWidget*, GdkEvent* event)
-{
-	GdkEventCrossing* crossing_event = reinterpret_cast<GdkEventCrossing*>(event);
-	if ((crossing_event->detail == GDK_NOTIFY_INFERIOR)
-			|| (crossing_event->mode != GDK_CROSSING_NORMAL))
-	{
-		return false;
-	}
-
-	grab_pointer(GTK_WIDGET(m_window));
-
-	return false;
-}
-
-//-----------------------------------------------------------------------------
-
-gboolean WhiskerMenu::Window::on_button_press_event(GtkWidget*, GdkEvent* event)
+gboolean WhiskerMenu::Window::on_focus_out_event(GtkWidget* widget, GdkEvent*)
 {
 	if (wm_settings->stay_on_focus_out)
 	{
-		return false;
+		return GDK_EVENT_PROPAGATE;
 	}
 
-	// Hide menu if user clicks outside
-	GdkEventButton* button_event = reinterpret_cast<GdkEventButton*>(event);
-	if ((button_event->x_root <= m_geometry.x)
-			|| (button_event->x_root >= m_geometry.x + m_geometry.width)
-			|| (button_event->y_root <= m_geometry.y)
-			|| (button_event->y_root >= m_geometry.y + m_geometry.height))
+	if (!m_child_has_focus && gtk_widget_get_visible(widget))
 	{
 		hide();
+		m_plugin->focus_lost();
 	}
-	return false;
-}
 
-//-----------------------------------------------------------------------------
-
-gboolean WhiskerMenu::Window::on_button_release_event(GtkWidget*, GdkEvent*)
-{
-	unset_pressed_category();
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -671,10 +584,10 @@ gboolean WhiskerMenu::Window::on_key_press_event(GtkWidget* widget, GdkEvent* ev
 	GdkEventKey* key_event = reinterpret_cast<GdkEventKey*>(event);
 
 	// Hide if escape is pressed and there is no text in search entry
-	if ( (key_event->keyval == GDK_KEY_Escape) && exo_str_is_empty(gtk_entry_get_text(m_search_entry)) )
+	if ( (key_event->keyval == GDK_KEY_Escape) && xfce_str_is_empty(gtk_entry_get_text(m_search_entry)) )
 	{
 		hide();
-		return true;
+		return GDK_EVENT_STOP;
 	}
 
 	Page* page = nullptr;
@@ -682,11 +595,11 @@ gboolean WhiskerMenu::Window::on_key_press_event(GtkWidget* widget, GdkEvent* ev
 	{
 		page = m_search_results;
 	}
-	else if (m_favorites_button->get_active())
+	else if (m_favorites->get_button()->get_active())
 	{
 		page = m_favorites;
 	}
-	else if (m_recent_button->get_active())
+	else if (m_recent->get_button()->get_active())
 	{
 		page = m_recent;
 	}
@@ -701,7 +614,7 @@ gboolean WhiskerMenu::Window::on_key_press_event(GtkWidget* widget, GdkEvent* ev
 	{
 		if (GTK_IS_TREE_VIEW(view) && ((widget == view) || (gtk_window_get_focus(m_window) == view)))
 		{
-			gtk_widget_grab_focus(m_favorites_button->get_widget());
+			gtk_widget_grab_focus(m_favorites->get_button()->get_widget());
 			page->reset_selection();
 		}
 	}
@@ -724,12 +637,12 @@ gboolean WhiskerMenu::Window::on_key_press_event(GtkWidget* widget, GdkEvent* ev
 			else
 			{
 				page->select_first();
-				return true;
+				return GDK_EVENT_STOP;
 			}
 		}
 	}
 
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -743,13 +656,13 @@ gboolean WhiskerMenu::Window::on_key_press_event_after(GtkWidget* widget, GdkEve
 		GdkEventKey* key_event = reinterpret_cast<GdkEventKey*>(event);
 		if (key_event->is_modifier)
 		{
-			return false;
+			return GDK_EVENT_PROPAGATE;
 		}
 		gtk_widget_grab_focus(search_entry);
 		gtk_window_propagate_key_event(m_window, key_event);
-		return true;
+		return GDK_EVENT_STOP;
 	}
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -760,13 +673,10 @@ gboolean WhiskerMenu::Window::on_map_event(GtkWidget*, GdkEvent*)
 
 	gtk_window_set_keep_above(m_window, true);
 
-	// Track mouse clicks outside of menu
-	grab_pointer(GTK_WIDGET(m_window));
-
 	// Focus search entry
 	gtk_widget_grab_focus(GTK_WIDGET(m_search_entry));
 
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -779,7 +689,7 @@ gboolean WhiskerMenu::Window::on_state_flags_changed_event(GtkWidget* widget, Gt
 		gtk_window_present(m_window);
 	}
 
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -797,7 +707,7 @@ gboolean WhiskerMenu::Window::on_configure_event(GtkWidget*, GdkEvent* event)
 
 	check_scrollbar_needed();
 
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -853,7 +763,7 @@ gboolean WhiskerMenu::Window::on_draw_event(GtkWidget* widget, cairo_t* cr)
 		gtk_render_background(context, cr, 0.0, 0.0, width, height);
 	}
 
-	return false;
+	return GDK_EVENT_PROPAGATE;
 }
 
 //-----------------------------------------------------------------------------
@@ -905,10 +815,39 @@ void WhiskerMenu::Window::category_toggled()
 
 //-----------------------------------------------------------------------------
 
+void WhiskerMenu::Window::reset_default_button()
+{
+	switch (wm_settings->default_category)
+	{
+	case 1:
+		m_default_button = m_recent->get_button();
+		gtk_box_reorder_child(m_sidebar_buttons, m_recent->get_button()->get_widget(), 0);
+		gtk_box_reorder_child(m_sidebar_buttons, m_favorites->get_button()->get_widget(), 1);
+		gtk_box_reorder_child(m_sidebar_buttons, m_applications->get_button()->get_widget(), 2);
+		break;
+
+	case 2:
+		m_default_button = m_applications->get_button();
+		gtk_box_reorder_child(m_sidebar_buttons, m_applications->get_button()->get_widget(), 0);
+		gtk_box_reorder_child(m_sidebar_buttons, m_favorites->get_button()->get_widget(), 1);
+		gtk_box_reorder_child(m_sidebar_buttons, m_recent->get_button()->get_widget(), 2);
+		break;
+
+	default:
+		m_default_button = m_favorites->get_button();
+		gtk_box_reorder_child(m_sidebar_buttons, m_favorites->get_button()->get_widget(), 0);
+		gtk_box_reorder_child(m_sidebar_buttons, m_recent->get_button()->get_widget(), 1);
+		gtk_box_reorder_child(m_sidebar_buttons, m_applications->get_button()->get_widget(), 2);
+		break;
+	}
+}
+
+//-----------------------------------------------------------------------------
+
 void WhiskerMenu::Window::show_favorites()
 {
 	// Switch to favorites panel
-	m_favorites_button->set_active(true);
+	m_favorites->get_button()->set_active(true);
 
 	// Clear search entry
 	gtk_entry_set_text(m_search_entry, "");
@@ -933,7 +872,7 @@ void WhiskerMenu::Window::search()
 {
 	// Fetch search string
 	const gchar* text = gtk_entry_get_text(m_search_entry);
-	if (exo_str_is_empty(text))
+	if (xfce_str_is_empty(text))
 	{
 		text = nullptr;
 	}
@@ -955,15 +894,6 @@ void WhiskerMenu::Window::search()
 
 //-----------------------------------------------------------------------------
 
-void WhiskerMenu::Window::unset_pressed_category()
-{
-	// Force a state change on sidebar buttons
-	gtk_widget_set_sensitive(GTK_WIDGET(m_sidebar_buttons), false);
-	gtk_widget_set_sensitive(GTK_WIDGET(m_sidebar_buttons), true);
-}
-
-//-----------------------------------------------------------------------------
-
 void WhiskerMenu::Window::update_layout()
 {
 	// Set vertical position of commands
@@ -1058,41 +988,64 @@ void WhiskerMenu::Window::update_layout()
 	}
 
 	// Arrange vertical order of header, applications, and search
+	const int window_border_width = gtk_container_get_border_width(GTK_CONTAINER(m_vbox));
+	GtkWidget* search = GTK_WIDGET(m_search_box);
+	GtkWidget* title = GTK_WIDGET(m_title_box);
 	if (m_layout_bottom && m_layout_search_alternate)
 	{
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_title_box), 0);
+		gtk_box_reorder_child(m_vbox, title, 0);
 		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_contents_stack), 1);
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_search_box), 2);
+		gtk_box_reorder_child(m_vbox, search, 2);
 
 		m_search_cover = GTK_STACK_TRANSITION_TYPE_OVER_UP;
 		m_search_uncover = GTK_STACK_TRANSITION_TYPE_UNDER_DOWN;
+
+		gtk_widget_set_margin_top(title, 0);
+		gtk_widget_set_margin_bottom(title, window_border_width);
+		gtk_widget_set_margin_top(search, 6);
+		gtk_widget_set_margin_bottom(search, 0);
 	}
 	else if (m_layout_search_alternate)
 	{
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_title_box), 2);
+		gtk_box_reorder_child(m_vbox, title, 2);
 		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_contents_stack), 1);
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_search_box), 0);
+		gtk_box_reorder_child(m_vbox, search, 0);
 
 		m_search_cover = GTK_STACK_TRANSITION_TYPE_OVER_DOWN;
 		m_search_uncover = GTK_STACK_TRANSITION_TYPE_UNDER_UP;
+
+		gtk_widget_set_margin_top(title, window_border_width);
+		gtk_widget_set_margin_bottom(title, 0);
+		gtk_widget_set_margin_top(search, 0);
+		gtk_widget_set_margin_bottom(search, 6);
 	}
 	else if (m_layout_bottom)
 	{
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_title_box), 0);
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_search_box), 1);
+		gtk_box_reorder_child(m_vbox, title, 0);
+		gtk_box_reorder_child(m_vbox, search, 1);
 		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_contents_stack), 2);
 
 		m_search_cover = GTK_STACK_TRANSITION_TYPE_OVER_DOWN;
 		m_search_uncover = GTK_STACK_TRANSITION_TYPE_UNDER_UP;
+
+		gtk_widget_set_margin_top(title, 0);
+		gtk_widget_set_margin_bottom(title, window_border_width);
+		gtk_widget_set_margin_top(search, 0);
+		gtk_widget_set_margin_bottom(search, 6);
 	}
 	else
 	{
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_title_box), 2);
-		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_search_box), 1);
+		gtk_box_reorder_child(m_vbox, title, 2);
+		gtk_box_reorder_child(m_vbox, search, 1);
 		gtk_box_reorder_child(m_vbox, GTK_WIDGET(m_contents_stack), 0);
 
 		m_search_cover = GTK_STACK_TRANSITION_TYPE_OVER_UP;
 		m_search_uncover = GTK_STACK_TRANSITION_TYPE_UNDER_DOWN;
+
+		gtk_widget_set_margin_top(title, window_border_width);
+		gtk_widget_set_margin_bottom(title, 0);
+		gtk_widget_set_margin_top(search, 6);
+		gtk_widget_set_margin_bottom(search, 0);
 	}
 }
 
